from aiida.work.workchain import WorkChain
from aiida.orm.data.base import NumericType

class ZombieWorkChain(WorkChain):

    @classmethod
    def define(cls, spec):
        super(ZombieWorkChain, cls).define(spec)
        spec.outline(
            cls._step1,
            cls._step2,
            cls._step3
        )
        spec.output('out', valid_type=NumericType)

    def _step1(self):
        print 'I am a zombie'

    def _step2(self):
        raise Exception()

    def _step3(self):
        # This step is never reached
        pass



from aiida.work.daemon import tick_workflow_engine
from argparse import ArgumentParser
import sys
from time import sleep

if __name__ == '__main__':
    
	tick_workflow_engine()

    #parser = ArgumentParser()
    #parser.add_argument('-n', required=False, type=int, default=1)
    #parser.add_argument('-s', '--sleep', required=False, type=float, default=0)
    #parsed = parser.parse_args(sys.argv[1:])
    #for i in range(parsed.n):
    #    print "Ticking workflows"
    #    tick_workflow_engine()
    #    sleep(parsed.sleep)



from aiida.work.workchain import WorkChain
from aiida.orm.data.base import NumericType


class ZombieWorkChain(WorkChain):
    @classmethod
    def define(cls, spec):
        super(ZombieWorkChain, cls).define(spec)
        spec.output('out', valid_type=NumericType)
        spec.outline(cls._step1, cls._step2, cls._step3)
    def _step1(self):
        print 'I am a zombie'
    def _step2(self):
        raise Exception()
    def _step3(self):
        # This step is never reached
        pass




#!/usr/bin/env runaiida
# -*- coding: utf-8 -*-
###########################################################################
# Copyright (c), The AiiDA team. All rights reserved.                     #
# This file is part of the AiiDA code.                                    #
#                                                                         #
# The code is hosted on GitHub at https://github.com/aiidateam/aiida_core #
# For further information on the license, see the LICENSE.txt file        #
# For further information please visit http://www.aiida.net               #
###########################################################################
from aiida.work.run import run
from aiida.workflows.user.workchain import ParentWorkChain
from aiida.work.runner import create_runner, create_daemon_runner
from aiida.work.launch import run_get_pid

runner = create_runner()
# runner = create_daemon_runner()

# runner.run(ParentWorkChain)
result = run_get_pid(ParentWorkChain)
print result
# running = submit(ParentWorkChain)
# print('Submitted {}'.format(running.pid))



# -*- coding: utf-8 -*-
###########################################################################
# Copyright (c), The AiiDA team. All rights reserved.                     #
# This file is part of the AiiDA code.                                    #
#                                                                         #
# The code is hosted on GitHub at https://github.com/aiidateam/aiida_core #
# For further information on the license, see the LICENSE.txt file        #
# For further information please visit http://www.aiida.net               #
###########################################################################
from time import sleep
# from aiida.work.run import submit
from aiida.work.workchain import WorkChain, ToContext

class ParentWorkChain(WorkChain):

    @classmethod
    def define(cls, spec):
        super(ParentWorkChain, cls).define(spec)
        spec.outline(
            cls.step,
            cls.resulta
        )

    def step(self):
        running = self.runner.submit(SubWorkChain)
        self.report('Submitted {}<{}>'.format(SubWorkChain.__name__, running.pid))
        return ToContext(sub=running)

    def resulta(self):
        self.report('ParentWorkChain finished')

class SubWorkChain(WorkChain):

    @classmethod
    def define(cls, spec):
        super(SubWorkChain, cls).define(spec)
        spec.outline(
            cls.step,
            cls.resulta,
            cls.result2,
            cls.step2,
            cls.result3
        )

    def step(self):
        running = self.runner.submit(BaseWorkChain)
        self.report('Submitted {}<{}>'.format(BaseWorkChain.__name__, running.pid))
        return ToContext(base=running)

    def resulta(self):
        self.report('SubWorkChain finished')

    def result2(self):
        self.report('SubWorkChain 2')

    def step2(self):
        running = self.runner.submit(BaseWorkChain)
        self.report('Submitted {}<{}>'.format(BaseWorkChain.__name__, running.pid))
        return ToContext(base=running)

    def result3(self):
        self.report('SubWorkChain 3')

class BaseWorkChain(WorkChain):

    @classmethod
    def define(cls, spec):
        super(BaseWorkChain, cls).define(spec)
        spec.outline(
            cls.step
        )

    def step(self):
        self.report('huzzah')
